==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fAaload.h <==
// class soot.coffi.Instruction_Aaload

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 9e697838889b9644 soot_coffi_Instruction__5fAaload
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fAaload_H_
#define _JC_soot_coffi_Instruction__5fAaload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fAaload$sub_refs	_jc_soot_coffi_Instruction__5fAaload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fAaload$sub_nonrefs	_jc_soot_coffi_Instruction__5fAaload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAaload$refs	_jc_soot_coffi_Instruction__5fAaload$refs;
typedef struct _jc_soot_coffi_Instruction__5fAaload$nonrefs	_jc_soot_coffi_Instruction__5fAaload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAaload$object	_jc_soot_coffi_Instruction__5fAaload$object;

typedef const struct _jc_soot_coffi_Instruction__5fAaload$vmethods	_jc_soot_coffi_Instruction__5fAaload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fAaload$vtable	_jc_soot_coffi_Instruction__5fAaload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fAaload$vtype	_jc_soot_coffi_Instruction__5fAaload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fAaload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fAaload$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fAaload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fAaload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fAaload$vmethods	soot_coffi_Instruction__5fAaload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fAaload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fAaload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAaload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAaload$refs {
    _jc_soot_coffi_Instruction__5fAaload$sub_refs	soot_coffi_Instruction__5fAaload;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAaload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAaload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fAaload$sub_nonrefs	soot_coffi_Instruction__5fAaload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fAaload$object {
	_jc_soot_coffi_Instruction__5fAaload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fAaload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fAaload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fAaload$vtype _jc_soot_coffi_Instruction__5fAaload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fAaload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fAaload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fAaload_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fAaload.h <==
// class soot.coffi.Instruction_Aaload

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 9e697838889b9644 soot_coffi_Instruction__5fAaload
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fAaload_H_
#define _JC_soot_coffi_Instruction__5fAaload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fAaload$sub_refs	_jc_soot_coffi_Instruction__5fAaload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fAaload$sub_nonrefs	_jc_soot_coffi_Instruction__5fAaload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAaload$refs	_jc_soot_coffi_Instruction__5fAaload$refs;
typedef struct _jc_soot_coffi_Instruction__5fAaload$nonrefs	_jc_soot_coffi_Instruction__5fAaload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAaload$object	_jc_soot_coffi_Instruction__5fAaload$object;

typedef const struct _jc_soot_coffi_Instruction__5fAaload$vmethods	_jc_soot_coffi_Instruction__5fAaload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fAaload$vtable	_jc_soot_coffi_Instruction__5fAaload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fAaload$vtype	_jc_soot_coffi_Instruction__5fAaload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fAaload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fAaload$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fAaload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fAaload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fAaload$vmethods	soot_coffi_Instruction__5fAaload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fAaload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fAaload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAaload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAaload$refs {
    _jc_soot_coffi_Instruction__5fAaload$sub_refs	soot_coffi_Instruction__5fAaload;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAaload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAaload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fAaload$sub_nonrefs	soot_coffi_Instruction__5fAaload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fAaload$object {
	_jc_soot_coffi_Instruction__5fAaload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fAaload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fAaload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fAaload$vtype _jc_soot_coffi_Instruction__5fAaload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fAaload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fAaload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fAaload_H_ */
